@@ -46,6 +46,7 @@ from robotframework_ls.impl.robot_constants import (
     ROBOT_AND_TXT_FILE_EXTENSIONS,
 )
 import time
+import sys
 
 
 @lru_cache(None)
@@ -234,6 +235,22 @@ class _TestFrameInfo(_BaseFrameInfo):
         return "Test"
 
 
+class _LogFrameInfo(_BaseFrameInfo):
+    def __init__(self, stack_list, dap_frame):
+        self._stack_list = weakref.ref(stack_list)
+        self._dap_frame = dap_frame
+
+    @property
+    def dap_frame(self):
+        return self._dap_frame
+
+    def get_scopes(self) -> List[Scope]:
+        return []
+
+    def get_type_name(self):
+        return "Log"
+
+
 class _KeywordFrameInfo(_BaseFrameInfo):
     def __init__(
         self, stack_list, dap_frame, name, lineno, args, variables, execution_context
@@ -373,6 +390,21 @@ class _StackInfo(object):
         self._frame_id_to_frame_info[frame_id] = _TestFrameInfo(self, dap_frame)
         return frame_id
 
+    def add_log_entry_stack(self, name: str, filename: str, lineno: int) -> int:
+        from robocorp_ls_core.debug_adapter_core.dap import dap_schema
+
+        frame_id: int = next_id()
+        dap_frame = dap_schema.StackFrame(
+            frame_id,
+            name=name,
+            line=lineno,
+            column=0,
+            source=dap_schema.Source(name=os.path.basename(filename), path=filename),
+        )
+        self._dap_frames.append(dap_frame)
+        self._frame_id_to_frame_info[frame_id] = _LogFrameInfo(self, dap_frame)
+        return frame_id
+
     @property
     def dap_frames(self) -> List[StackFrame]:
         """
@@ -439,12 +471,44 @@ class _EvaluationInfo(object):
                 "Unable to find frame id for evaluation: %s" % (frame_id,)
             )
 
+        dap_frames = stack_info.dap_frames
+        if not dap_frames:
+            raise InvalidFrameIdError("No frames for evaluation.")
+
+        top_frame_id = dap_frames[0].id
+        if top_frame_id != frame_id:
+            if get_log_level() >= 2:
+                log.debug(
+                    "Unable to evaluate.\nFrame id for evaluation: %r\nTop frame id: %r.\nDAP frames:\n%s",
+                    frame_id,
+                    top_frame_id,
+                    "\n".join(x.to_json() for x in dap_frames),
+                )
+
+            raise UnableToEvaluateError(
+                "Keyword calls may only be evaluated at the topmost frame."
+            )
+
         info = stack_info._frame_id_to_frame_info.get(frame_id)
         if info is None:
             raise InvalidFrameIdError(
                 "Unable to find frame info for evaluation: %s" % (frame_id,)
             )
 
+        if isinstance(info, _LogFrameInfo):
+            if len(dap_frames) < 2:
+                raise InvalidFrameIdError(
+                    "Unable to evaluate in Log frame entry without a parent."
+                )
+
+            else:
+                frame_id = dap_frames[1].id
+                info = stack_info._frame_id_to_frame_info.get(frame_id)
+                if info is None:
+                    raise InvalidFrameIdError(
+                        "Unable to find frame info for evaluation: %s" % (frame_id,)
+                    )
+
         if not isinstance(info, _KeywordFrameInfo):
             raise InvalidFrameTypeError(
                 "Can only evaluate at a Keyword context (current context: %s)"
@@ -511,28 +575,12 @@ Evaluation
             node = usage.node
             name = usage.name
 
-            dap_frames = stack_info.dap_frames
-            if dap_frames:
-                top_frame_id = dap_frames[0].id
-                if top_frame_id != frame_id:
-                    if get_log_level() >= 2:
-                        log.debug(
-                            "Unable to evaluate.\nFrame id for evaluation: %r\nTop frame id: %r.\nDAP frames:\n%s",
-                            frame_id,
-                            top_frame_id,
-                            "\n".join(x.to_json() for x in dap_frames),
-                        )
+            assign = node.assign
+            from robot.running import Keyword
 
-                    raise UnableToEvaluateError(
-                        "Keyword calls may only be evaluated at the topmost frame."
-                    )
-
-                assign = node.assign
-                from robot.running import Keyword
-
-                kw = Keyword(name, args=node.args, assign=assign)
-                ctx = info.execution_context
-                return EvaluationResult(kw.run(ctx))
+            kw = Keyword(name, args=node.args, assign=assign)
+            ctx = info.execution_context
+            return EvaluationResult(kw.run(ctx))
 
         raise UnableToEvaluateError("Unable to evaluate: %s" % (self.expression,))
 
@@ -710,7 +758,7 @@ class _RobotDebuggerImpl(object):
                     name = "Log (%s)" % (entry.name,)
                     filename = self._get_filename(entry, "Log")
 
-                    frame_id = stack_info.add_test_entry_stack(
+                    frame_id = stack_info.add_log_entry_stack(
                         name, filename, entry.lineno
                     )
             except:
@@ -851,18 +899,14 @@ class _RobotDebuggerImpl(object):
         name = attributes["kwname"]
         args = attributes["args"]
         entry_type = attributes.get("type", "KEYWORD")
-        if attributes.get("status") == "NOT RUN":
-            return
         if not args:
             args = []
-        self._before_run_step(ctx, name, entry_type, lineno, source, args)
+        self._before_run_step(
+            ctx, name, entry_type, lineno, source, args, attributes.get("status")
+        )
 
     # 4.0 versions where the lineno is available on the V2 listener
     def end_keyword_v2(self, name, attributes):
-
-        if attributes.get("status") == "NOT RUN":
-            return
-
         self._after_run_step()
 
     # 3.x versions where the lineno is NOT available on the V2 listener
@@ -887,14 +931,17 @@ class _RobotDebuggerImpl(object):
             lineno = control_flow_stmt.lineno
             source = control_flow_stmt.source
         except AttributeError:
-            return
+            lineno = -1
+            source = None
 
         try:
             args = control_flow_stmt.args
         except AttributeError:
             args = []
         entry_type = "KEYWORD"
-        self._before_run_step(ctx, name, entry_type, lineno, source, args)
+        self._before_run_step(
+            ctx, name, entry_type, lineno, source, args, status="NOT AVAILABLE"
+        )
 
     # 3.x versions where the lineno is NOT available on the V2 listener
     def after_control_flow_stmt(self, control_flow_stmt, ctx, *args, **kwargs):
@@ -912,14 +959,17 @@ class _RobotDebuggerImpl(object):
             lineno = step.lineno
             source = step.source
         except AttributeError:
-            return
+            lineno = -1
+            source = None
         try:
             args = step.args
         except AttributeError:
             args = []
         ctx = runner._context
         entry_type = "KEYWORD"
-        self._before_run_step(ctx, name, entry_type, lineno, source, args)
+        self._before_run_step(
+            ctx, name, entry_type, lineno, source, args, status="NOT AVAILABLE"
+        )
 
     def after_keyword_runner(self, runner, step, *args, **kwargs):
         self._after_run_step()
@@ -936,14 +986,17 @@ class _RobotDebuggerImpl(object):
             lineno = step.lineno
             source = step.source
         except AttributeError:
-            return
+            lineno = -1
+            source = None
         try:
             args = step.args
         except AttributeError:
             args = []
         ctx = step_runner._context
         entry_type = "KEYWORD"
-        self._before_run_step(ctx, name, entry_type, lineno, source, args)
+        self._before_run_step(
+            ctx, name, entry_type, lineno, source, args, status="NOT AVAILABLE"
+        )
 
     # 3.x versions where the lineno is NOT available on the V2 listener
     def after_run_step(self, step_runner, step, name=None):
@@ -963,7 +1016,7 @@ class _RobotDebuggerImpl(object):
             "WHILE",
         )
 
-    def _before_run_step(self, ctx, name, entry_type, lineno, source, args):
+    def _before_run_step(self, ctx, name, entry_type, lineno, source, args, status):
         if entry_type == "KEYWORD":
             self._ignore_failures_in_stack.push(name)
 
@@ -973,7 +1026,12 @@ class _RobotDebuggerImpl(object):
         if self._is_control_step(entry_type):
             self._stop_on_stack_len += 1
 
-        if source is None or lineno is None:
+        if source and not source.endswith(ROBOT_AND_TXT_FILE_EXTENSIONS):
+            robot_init = os.path.join(source, "__init__.robot")
+            if os.path.exists(robot_init):
+                source = robot_init
+
+        if not source or lineno is None:
             # RunKeywordIf doesn't have a source, so, just show the caller source.
             for entry in reversed(self._stack_ctx_entries_deque):
                 if source is None:
@@ -982,17 +1040,19 @@ class _RobotDebuggerImpl(object):
                     lineno = entry.lineno
                 break
 
-        if not source:
-            return
-        if not source.endswith(ROBOT_AND_TXT_FILE_EXTENSIONS):
-            robot_init = os.path.join(source, "__init__.robot")
-            if os.path.exists(robot_init):
-                source = robot_init
         self._stack_ctx_entries_deque.append(
             _StepEntry(
-                name, lineno, source, args, ctx.variables.current, entry_type, ctx
+                name,
+                lineno,
+                source if source else "<not available>",
+                args,
+                ctx.variables.current,
+                entry_type,
+                ctx,
             )
         )
+        if not source or status == "NOT RUN":
+            return
         if self._skip_breakpoints:
             return
 
@@ -1101,7 +1161,59 @@ class _RobotDebuggerImpl(object):
         )
 
     def end_suite(self, data, result):
-        self._stack_ctx_entries_deque.pop()
+        self._pop("SUITE", data.name)
+
+    def _pop(self, entry_type, name):
+        if not self._stack_ctx_entries_deque:
+            self._log_critical_stack(
+                f"Robot Debugger Warning: unable to pop {entry_type} - {name} (empty queue)."
+            )
+        else:
+            stack_entry = self._stack_ctx_entries_deque[-1]
+            if stack_entry.entry_type == entry_type and stack_entry.name == name:
+                self._stack_ctx_entries_deque.pop()
+            else:
+                for i, stack_entry in enumerate(
+                    reversed(self._stack_ctx_entries_deque)
+                ):
+                    if (
+                        stack_entry.entry_type == entry_type
+                        and stack_entry.name == name
+                    ):
+                        for _ in range(i):
+                            stack_entry = self._stack_ctx_entries_deque.pop()
+                            self._log_critical_stack(
+                                f"Robot Debugger Warning: {stack_entry.entry_type} - {stack_entry.name} did not have a corresponding pop."
+                            )
+
+                        # The current one (which is a match).
+                        self._stack_ctx_entries_deque.pop()
+                        return
+
+                if entry_type in ("TEST", "SUITE"):
+                    for i, stack_entry in enumerate(
+                        reversed(self._stack_ctx_entries_deque)
+                    ):
+                        if stack_entry.entry_type == entry_type:
+                            for _ in range(i):
+                                stack_entry = self._stack_ctx_entries_deque.pop()
+                                self._log_critical_stack(
+                                    f"Robot Debugger Warning: {stack_entry.entry_type} - {stack_entry.name} did not have a corresponding pop."
+                                )
+
+                            # The current one (which is a partial match).
+                            stack_entry = self._stack_ctx_entries_deque.pop()
+                            self._log_critical_stack(
+                                f"Robot Debugger Warning: {stack_entry.entry_type} - {stack_entry.name} pop just by type. Actual request: {entry_type} - {name}"
+                            )
+                            return
+
+                self._log_critical_stack(
+                    f"Robot Debugger Warning: unable to pop {entry_type} - {name} because it does not match the current top: {stack_entry.entry_type} - {stack_entry.name}"
+                )
+
+    def _log_critical_stack(self, msg):
+        log.critical(msg)
 
     def start_test(self, data, result):
         self._stack_ctx_entries_deque.append(
@@ -1109,7 +1221,7 @@ class _RobotDebuggerImpl(object):
         )
 
     def end_test(self, data, result):
-        self._stack_ctx_entries_deque.pop()
+        self._pop("TEST", data.name)
 
     def log_message(self, message, skip_error=True):
         from robotframework_debug_adapter.message_utils import (
@@ -1134,6 +1246,7 @@ class _RobotDebuggerImpl(object):
         try:
             source = None
             lineno = None
+            path = None
 
             source_and_line = extract_source_and_line_from_message(message.message)
 
