@@ -598,7 +598,8 @@ def main():
     robot_args = args[3:]
 
     # Always add the listener (because even when not debugging we want
-    # to be able to provide output messages for logging).
+    # to be able to provide output messages for logging as well as
+    # information to be show in the `Robot Output` View).
     robot_args = [
         "--listener=robotframework_debug_adapter.listeners.DebugListener",
         "--listener=robotframework_debug_adapter.listeners.DebugListenerV2",
@@ -652,6 +653,10 @@ def main():
             sys.stderr.write("Python executable: %s.\n\n" % (sys.executable,))
             raise
 
+        from robotframework_debug_adapter.listeners import install_rf_stream_connection
+
+        install_rf_stream_connection(processor.write_message)
+
         from robot import run_cli
 
         exitcode = run_cli(robot_args, exit=False)
