@@ -3,7 +3,14 @@ import re
 import sys
 from typing import Dict, Optional, List, Tuple
 
-from robocorp_ls_core.lsp import DiagnosticSeverity, DiagnosticTag
+from robocorp_ls_core.lsp import (
+    DiagnosticSeverity,
+    DiagnosticTag,
+    ICustomDiagnosticDataUndefinedKeywordTypedDict,
+    ICustomDiagnosticDataUndefinedResourceTypedDict,
+    ICustomDiagnosticDataUndefinedVarImportTypedDict,
+    ICustomDiagnosticDataUndefinedLibraryTypedDict,
+)
 from robocorp_ls_core.protocols import check_implements
 from robocorp_ls_core.robotframework_log import get_logger
 from robotframework_ls.impl.ast_utils import MAX_ERRORS
@@ -310,13 +317,19 @@ def collect_analysis_errors(initial_completion_context):
                     if "{" in library_name and resolved_name:
                         error_msg += f"\nNote: resolved name: {resolved_name}"
 
-            errors.append(
-                ast_utils.Error(
-                    f"Unresolved library: {library_name}.{error_msg}{additional}".strip(),
-                    start,
-                    end,
-                )
+            error = ast_utils.Error(
+                f"Unresolved library: {library_name}.{error_msg}{additional}".strip(),
+                start,
+                end,
             )
+            undefined_var_import_data: ICustomDiagnosticDataUndefinedLibraryTypedDict = {
+                "kind": "undefined_library",
+                "name": library_name,
+                "resolved_name": resolved_name,
+            }
+            error.data = undefined_var_import_data
+
+            errors.append(error)
 
     def on_unresolved_resource(
         completion_context: ICompletionContext,
@@ -346,7 +359,14 @@ def collect_analysis_errors(initial_completion_context):
                 if "{" in resource_name and resolved_name:
                     error_msg += f"\nNote: resolved name: {resolved_name}"
 
-            errors.append(ast_utils.Error(error_msg, start, end))
+            error = ast_utils.Error(error_msg, start, end)
+            undefined_resource_data: ICustomDiagnosticDataUndefinedResourceTypedDict = {
+                "kind": "undefined_resource",
+                "name": resource_name,
+                "resolved_name": resolved_name,
+            }
+            error.data = undefined_resource_data
+            errors.append(error)
 
     collector = _AnalysisKeywordsCollector(
         on_unresolved_library,
@@ -386,6 +406,11 @@ def collect_analysis_errors(initial_completion_context):
                     "Undefined keyword: %s." % (keyword_usage_info.name,),
                     tokens=[keyword_usage_info.token],
                 )
+                undefined_keyword_data: ICustomDiagnosticDataUndefinedKeywordTypedDict = {
+                    "kind": "undefined_keyword",
+                    "name": keyword_usage_info.name,
+                }
+                error.data = undefined_keyword_data
                 errors.append(error)
 
             else:
@@ -508,7 +533,7 @@ def collect_analysis_errors(initial_completion_context):
                     if keyword_token is not None:
                         # Ok, we found the keyword, let's check if the arguments are correct.
                         keyword_argument_analysis = KeywordArgumentAnalysis(
-                            keyword_found.keyword_args
+                            keyword_found.keyword_args, keyword_found
                         )
 
                         for (
@@ -537,7 +562,7 @@ def collect_analysis_errors(initial_completion_context):
                                 stack, keyword_usage_info.node
                             ):
                                 keyword_argument_analysis = KeywordArgumentAnalysis(
-                                    keyword_found.keyword_args
+                                    keyword_found.keyword_args, keyword_found
                                 )
                                 args_tokens = template_arguments_node_info.node.tokens
                                 for (
@@ -722,9 +747,14 @@ def _collect_undefined_variables_errors(initial_completion_context):
                 if "{" in variable_import_name and resolved_name:
                     error_msg += f"\nNote: resolved name: {resolved_name}"
 
-            unresolved_variable_import_errors.append(
-                ast_utils.Error(error_msg, start, end)
-            )
+            error = ast_utils.Error(error_msg, start, end)
+            undefined_var_import_data: ICustomDiagnosticDataUndefinedVarImportTypedDict = {
+                "kind": "undefined_var_import",
+                "name": variable_import_name,
+                "resolved_name": resolved_name,
+            }
+            error.data = undefined_var_import_data
+            unresolved_variable_import_errors.append(error)
 
     from robotframework_ls.impl import variable_completions
 
