@@ -100,8 +100,8 @@ class CompletionContext(object):
     def __init__(
         self,
         doc,
-        line=Sentinel.SENTINEL,
-        col=Sentinel.SENTINEL,
+        line=Sentinel.SENTINEL,  # 0-based
+        col=Sentinel.SENTINEL,  # 0-based
         workspace: Optional[IWorkspace] = None,
         config: Optional[IConfig] = None,
         memo: Optional[_Memo] = None,
@@ -110,6 +110,7 @@ class CompletionContext(object):
             IVariablesFromArgumentsFileLoader
         ] = (),
         lsp_messages: Optional[LSPMessages] = None,
+        tracing: bool = False,
     ) -> None:
         if col is Sentinel.SENTINEL or line is Sentinel.SENTINEL:
             assert (
@@ -141,6 +142,7 @@ class CompletionContext(object):
         self._monitor = monitor or NULL
         self.type = CompletionType.regular
         self.lsp_messages = lsp_messages
+        self.tracing = tracing
 
         # Note: it's None until it's requested in obtain_symbols_cache_reverse_index().
         # At that point it's obtained and synchronized accordingly (then, any copy
@@ -206,15 +208,22 @@ class CompletionContext(object):
     def create_copy(self, doc: IRobotDocument) -> ICompletionContext:
         return self.create_copy_doc_line_col(doc, line=0, col=0)
 
+    def create_copy_with_config(self, config: IConfig) -> "ICompletionContext":
+        return self.create_copy_doc_line_col(
+            doc=self._doc, line=self.sel.line, col=self.sel.col, config=config
+        )
+
     def create_copy_doc_line_col(
-        self, doc: IRobotDocument, line: int, col: int
+        self, doc: IRobotDocument, line: int, col: int, config: Optional[IConfig] = None
     ) -> ICompletionContext:
+        if config is None:
+            config = self._config
         ctx = CompletionContext(
             doc,
             line=line,
             col=col,
             workspace=self._workspace,
-            config=self._config,
+            config=config,
             memo=self._memo,
             monitor=self._monitor,
             variables_from_arguments_files_loader=self.variables_from_arguments_files_loader,
@@ -418,6 +427,12 @@ class CompletionContext(object):
         ret = []
         for library_import in ast_utils.iter_library_imports(ast):
             if library_import.node.name:
+                if self.tracing:
+                    log.debug(
+                        "Found import node (in get_imported_libraries): %s (alias: %s)",
+                        library_import.node.name,
+                        library_import.node.alias,
+                    )
                 ret.append(library_import.node)
         return tuple(ret)
 
