@@ -111,6 +111,7 @@ def _compute_symbols_from_ast(completion_context: ICompletionContext) -> ISymbol
     from robotframework_ls.impl.variable_completions import (
         collect_current_doc_global_variables,
     )
+    from robotframework_ls.impl import text_utilities
 
     doc = completion_context.doc
 
@@ -146,7 +147,15 @@ def _compute_symbols_from_ast(completion_context: ICompletionContext) -> ISymbol
     for keyword_usage_info in ast_utils.iter_keyword_usage_tokens(
         ast, collect_args_as_keywords=True
     ):
-        keywords_used.add(normalize_robot_name(keyword_usage_info.name))
+        normalized = normalize_robot_name(keyword_usage_info.name)
+        keywords_used.add(normalized)
+
+        for name, remainder in text_utilities.iter_dotted_names(
+            normalize_robot_name(keyword_usage_info.name)
+        ):
+            if not name or not remainder:
+                continue
+            keywords_used.add(remainder)
 
     test_info = list_tests(completion_context)
     test_info_for_cache: List[ITestInfoFromSymbolsCacheTypedDict] = [
@@ -309,6 +318,12 @@ class WorkspaceIndexer(object):
         return True
 
     def _on_thread(self) -> None:
+        try:
+            self._on_thread_internal()
+        except:
+            log.exception("Error in workpace indexer.")
+
+    def _on_thread_internal(self) -> None:
         if not self._collect_tests:
             for _uri, symbols_cache in self.iter_uri_and_symbols_cache():
                 # Do a single collection at startup, afterwards only
@@ -488,6 +503,10 @@ class WorkspaceIndexer(object):
                 yield uri, None  # i.e.: No longer there...
                 continue
 
+            # Note that this can be accessed in multiple threads... We let it
+            # compute at the same time but only one will be saved in the end
+            # (which means we'll spend some more cpu cycles but we shouldn't
+            # have any bad behavior due to it).
             symbols_cache = doc.symbols_cache
             if symbols_cache is None:
                 from robotframework_ls.impl.completion_context import (
@@ -540,9 +559,12 @@ class RobotWorkspace(Workspace):
             self, root_uri, fs_observer, workspace_folders=workspace_folders
         )
         self._generate_ast = generate_ast
+        self._lock_setup_workspace_indexer = threading.Lock()
         if collect_tests:
             assert endpoint is not None
-            assert index_workspace
+            assert (
+                index_workspace
+            ), "Can only collect tests when the workspace indexing is setup too."
 
         if index_workspace:
             self.workspace_indexer = WorkspaceIndexer(
@@ -555,6 +577,11 @@ class RobotWorkspace(Workspace):
             self.completion_context_workspace_caches.on_file_changed
         )
 
+    def setup_workspace_indexer(self):
+        with self._lock_setup_workspace_indexer:
+            assert self.workspace_indexer is None
+            self.workspace_indexer = WorkspaceIndexer(self, None, collect_tests=False)
+
     @overrides(Workspace.put_document)
     def put_document(self, text_document: TextDocumentItem) -> IDocument:
         doc = typing.cast(IRobotDocument, Workspace.put_document(self, text_document))
@@ -692,37 +719,72 @@ class RobotDocument(Document):
 
         return self.generate_ast_uncached()
 
-    def generate_ast_uncached(self):
-        from robot.api import get_model, get_resource_model, get_init_model  # noqa
+    def generate_ast_uncached(self) -> None:
+        from robot.api import get_model, get_resource_model, get_init_model
+        from robotframework_ls.impl.robot_localization import (
+            get_global_localization_info,
+        )
+        from robotframework_ls.impl import ast_utils
+        from robotframework_ls.impl.robot_version import robot_version_supports_language
+        from robotframework_ls.impl.robot_localization import LocalizationInfo
 
         try:
-            source = self.source
+            source: str = self.source
         except:
             log.exception("Error getting source for: %s" % (self.uri,))
             source = ""
 
+        language_codes: List[str] = []
         try:
+            kwargs: Dict[str, Any] = {}
+
+            if robot_version_supports_language():
+                try:
+                    # Input localization
+                    localization_info = get_global_localization_info()
+                    from robot.api import Languages
+
+                    languages = Languages()
+                    for code in localization_info.language_codes:
+                        languages.add_language(code)
+
+                    kwargs["lang"] = languages
+                except Exception:
+                    log.exception(
+                        "Error: Unable to use expected language API in this version of Robot Framework."
+                    )
+
             t = self.get_type()
             if t == self.TYPE_TEST_CASE:
-                ast = get_model(source)
+                ast = get_model(source, **kwargs)
 
             elif t == self.TYPE_RESOURCE:
-                ast = get_resource_model(source)
+                ast = get_resource_model(source, **kwargs)
 
             elif t == self.TYPE_INIT:
-                ast = get_init_model(source)
+                ast = get_init_model(source, **kwargs)
 
             else:
                 log.critical("Unrecognized section: %s", t)
-                ast = get_model(source)
+                ast = get_model(source, **kwargs)
+
+            # Output localization
+            if robot_version_supports_language():
+                language_codes.extend(getattr(ast, "languages", ()))
+
+            localization_info = LocalizationInfo(tuple(language_codes))
 
             ast.source = self.path
+            ast_utils.set_localization_info_in_model(ast, localization_info)
             return ast
         except:
-            log.critical(f"Error parsing {self.uri}")
+            log.exception(f"Error parsing {self.uri}")
             # Note: we always want to return a valid AST here (the
             # AST itself should have the error).
             ast = get_model(f"*** Unable to parse: {self.uri} ***")
+
+            localization_info = LocalizationInfo(tuple(language_codes))
+            ast_utils.set_localization_info_in_model(ast, localization_info)
             ast.source = self.path
             return ast
 
