@@ -12,6 +12,7 @@ import time
 from robotframework_ls.constants import (
     DEFAULT_COMPLETIONS_TIMEOUT,
     DEFAULT_COLLECT_DOCS_TIMEOUT,
+    DEFAULT_LIST_TESTS_TIMEOUT,
 )
 from robocorp_ls_core.robotframework_log import get_logger
 from typing import Any, Optional, Dict, Sequence, Set, ContextManager, Union
@@ -24,6 +25,7 @@ from robocorp_ls_core.protocols import (
     IEndPoint,
     IProgressReporter,
     ActionResultDict,
+    IFuture,
 )
 from pathlib import Path
 from robotframework_ls.ep_providers import (
@@ -46,6 +48,9 @@ from robocorp_ls_core.lsp import (
     RenameParamsTypedDict,
     PrepareRenameParamsTypedDict,
     SelectionRangeParamsTypedDict,
+    TextDocumentCodeActionTypedDict,
+    WorkspaceEditParamsTypedDict,
+    ShowDocumentParamsTypedDict,
 )
 from robotframework_ls.commands import (
     ROBOT_GET_RFLS_HOME_DIR,
@@ -57,9 +62,12 @@ from robotframework_ls.commands import (
     ROBOT_LINT_EXPLORER,
     ROBOT_GENERATE_FLOW_EXPLORER_MODEL,
     ROBOT_COLLECT_ROBOT_DOCUMENTATION,
+    ROBOT_CONVERT_OUTPUT_XML_TO_ROBOSTREAM,
+    ROBOT_APPLY_CODE_ACTION,
 )
 from robocorp_ls_core.jsonrpc.exceptions import JsonRpcException
 import weakref
+from io import StringIO
 
 
 log = get_logger(__name__)
@@ -399,6 +407,10 @@ class RobotFrameworkLanguageServer(PythonLanguageServer):
             self._server_manager, self
         )
 
+    def _execute_on_main_thread(self, on_main_thread_callback):
+        read_queue = self._jsonrpc_stream_reader.get_read_queue()
+        read_queue.put(on_main_thread_callback)
+
     def get_remote_fs_observer_port(self) -> Optional[int]:
         from robocorp_ls_core.remote_fs_observer_impl import RemoteFSObserver
 
@@ -483,7 +495,7 @@ class RobotFrameworkLanguageServer(PythonLanguageServer):
         from robotframework_ls import commands
 
         server_capabilities = {
-            "codeActionProvider": False,
+            "codeActionProvider": {"resolveProvider": False},
             "codeLensProvider": {"resolveProvider": True},
             # Docs are lazily computed
             "completionProvider": {"resolveProvider": True},
@@ -657,6 +669,52 @@ class RobotFrameworkLanguageServer(PythonLanguageServer):
         log.info("Unable to provide evaluatable expression (no api available).")
         return None
 
+    @command_dispatcher(ROBOT_CONVERT_OUTPUT_XML_TO_ROBOSTREAM)
+    def _convert_output_xml_to_rfstream(self, opts: Dict[str, Any]):
+        def convert_in_thread():
+            from robotframework_ls import import_robot_out_stream
+
+            import_robot_out_stream()
+
+            from robot_out_stream import xml_to_rfstream
+
+            source = opts.get("xml_path")
+            if source:
+                with tempfile.NamedTemporaryFile(
+                    "w", suffix=".robostream", delete=False
+                ) as temp:
+
+                    def write(contents):
+                        temp.write(contents)
+
+                    xml_to_rfstream.convert_xml_to_rfstream(source, write)
+
+                # Note that we just send the temp file if an input file was received
+                # (usually this should only happen if it's too big).
+                # The client is responsible for deleting it after using it.
+                return temp.name
+
+            # We received contents (return contents too).
+            xml_contents = opts.get("xml_contents")
+            if xml_contents is None:
+                raise RuntimeError(
+                    f"Expected either xml_path or xml_contents. Keys: {list(opts.keys())}"
+                )
+
+            source = StringIO()
+            source.write(xml_contents)
+            source.seek(0)
+
+            full_contents = []
+
+            def write2(contents):
+                full_contents.append(contents)
+
+            xml_to_rfstream.convert_xml_to_rfstream(source, write2)
+            return "".join(full_contents)
+
+        return convert_in_thread
+
     @command_dispatcher(ROBOT_WAIT_FULL_TEST_COLLECTION_INTERNAL)
     def _wait_for_full_test_collection(self, *arguments):
         rf_api_client = self._server_manager.get_regular_rf_api_client("")
@@ -852,10 +910,11 @@ class RobotFrameworkLanguageServer(PythonLanguageServer):
         rf_api_client = self._server_manager.get_others_api_client(doc_uri)
         if rf_api_client is not None:
             func = partial(
-                self._threaded_api_request,
+                self._threaded_api_request_no_doc,
                 rf_api_client,
                 "request_list_tests",
                 doc_uri=doc_uri,
+                __timeout__=DEFAULT_LIST_TESTS_TIMEOUT,
             )
             func = require_monitor(func)
             return func
@@ -1332,3 +1391,67 @@ class RobotFrameworkLanguageServer(PythonLanguageServer):
                 # so, we send it to all the APIs.
                 api.forward_async("cancelProgress", {"progressId": progressId})
         return True
+
+    def m_text_document__code_action(self, **kwargs):
+        params: TextDocumentCodeActionTypedDict = kwargs
+        # Sample params:
+        # {
+        #     "textDocument": {
+        #         "uri": "file:///x%3A/vscode-robot/local_test/robot_check/checkmy.robot"
+        #     },
+        #     "range": {
+        #         "start": {"line": 12, "character": 5},
+        #         "end": {"line": 12, "character": 5},
+        #     },
+        #     "context": {
+        #         "diagnostics": [
+        #             {
+        #                 "range": {
+        #                     "start": {"line": 12, "character": 4},
+        #                     "end": {"line": 12, "character": 8},
+        #                 },
+        #                 "message": "Undefined keyword: rara.",
+        #                 "severity": 1,
+        #                 "source": "robotframework",
+        #             }
+        #         ],
+        #         "triggerKind": 1,
+        #     },
+        # }
+        doc_uri = params["textDocument"]["uri"]
+        # Note: we have to use the "api" server which has symbols caches.
+        return self.async_api_forward(
+            "request_code_action", "api", doc_uri, params=params
+        )
+
+    @command_dispatcher(ROBOT_APPLY_CODE_ACTION)
+    def _apply_code_action(self, code_action_info):
+        weak_self = weakref.ref(self)
+
+        def in_thread(*args, **kwargs):
+            self = weak_self()
+            if self is None:
+                return
+
+            apply_edit: WorkspaceEditParamsTypedDict = code_action_info["apply_edit"]
+            fut: IFuture = self._lsp_messages.apply_edit_args(apply_edit)
+            try:
+                fut.result(4)
+            except:
+                log.exception(f"Exception calling: {self._lsp_messages.M_APPLY_EDIT}")
+
+            # Deal with linting (because if only a dependent file is changed we
+            # still want to ask for the main file to be linted).
+            lint_uris = code_action_info.get("lint_uris")
+            if lint_uris:
+                for uri in lint_uris:
+                    self._execute_on_main_thread(partial(self.lint, uri, is_saved=True))
+
+            # Force showing some document?
+            show_document_args: Optional[
+                ShowDocumentParamsTypedDict
+            ] = code_action_info.get("show_document")
+            log.info("Show document: %s", show_document_args)
+            self._lsp_messages.show_document(show_document_args)
+
+        return in_thread
