@@ -25,6 +25,9 @@ from robocorp_ls_core.lsp import (
     CompletionItemTypedDict,
     WorkspaceEditTypedDict,
     SelectionRangeTypedDict,
+    TextDocumentCodeActionTypedDict,
+    ICustomDiagnosticDataTypedDict,
+    CommandTypedDict,
 )
 from robotframework_ls.impl.protocols import (
     IKeywordFound,
@@ -40,6 +43,7 @@ import sys
 import threading
 from robocorp_ls_core.jsonrpc.exceptions import JsonRpcException
 import os
+from robocorp_ls_core import uris
 
 
 log = get_logger(__name__)
@@ -55,6 +59,7 @@ def complete_all(
     from robotframework_ls.impl import filesystem_section_completions
     from robotframework_ls.impl import keyword_parameter_completions
     from robotframework_ls.impl import auto_import_completions
+    from robotframework_ls.impl import library_names_completions
     from robotframework_ls.impl.collect_keywords import (
         collect_keyword_name_to_keyword_found,
     )
@@ -80,6 +85,7 @@ def complete_all(
                         completion_context, keyword_name_to_keyword_found
                     )
                 )
+                ret.extend(library_names_completions.complete(completion_context))
                 return ret
 
     if not ret:
@@ -229,6 +235,9 @@ class RobotFrameworkServerApi(PythonLanguageServer):
                 OPTION_ROBOT_VARIABLES_LOAD_FROM_ARGUMENTS_FILE, str, ""
             ).strip()
             if not variables_from_arguments_files:
+                log.debug(
+                    "%s not specified", OPTION_ROBOT_VARIABLES_LOAD_FROM_ARGUMENTS_FILE
+                )
                 self._variables_from_arguments_files_loader = []
 
             else:
@@ -240,12 +249,23 @@ class RobotFrameworkServerApi(PythonLanguageServer):
 
                 for v in variables_from_arguments_files.split(","):
                     v = v.strip()
+                    if not v:
+                        continue
                     created_variables_from_arguments_files.append(
                         VariablesFromArgumentsFileLoader(v)
                     )
+                created_variables_from_arguments_files = tuple(
+                    created_variables_from_arguments_files
+                )
                 self._variables_from_arguments_files_loader = (
                     created_variables_from_arguments_files
                 )
+
+                log.debug(
+                    "%s loaders: %s",
+                    OPTION_ROBOT_VARIABLES_LOAD_FROM_ARGUMENTS_FILE,
+                    created_variables_from_arguments_files,
+                )
         except:
             log.exception(
                 f"Error getting options: {OPTION_ROBOT_VARIABLES_LOAD_FROM_ARGUMENTS_FILE}"
@@ -752,6 +772,10 @@ class RobotFrameworkServerApi(PythonLanguageServer):
     def _create_completion_context(
         self, doc_uri, line, col, monitor: Optional[IMonitor]
     ):
+        """
+        :param line: 0-based
+        :param col: 0-based
+        """
         from robotframework_ls.impl.completion_context import CompletionContext
 
         if not self._check_and_log_rf_dependency_version():
@@ -888,12 +912,28 @@ class RobotFrameworkServerApi(PythonLanguageServer):
         self, doc_uri: str, monitor: IMonitor
     ) -> List[ITestInfoTypedDict]:
         from robotframework_ls.impl.code_lens import list_tests
+        from pathlib import Path
 
-        completion_context = self._create_completion_context(doc_uri, 0, 0, monitor)
-        if completion_context is None:
-            return []
+        path = Path(uris.to_fs_path(doc_uri))
+        if path.is_dir():
+            tests = []
+            for p in path.rglob("*.robot"):
+                doc_uri = uris.from_fs_path(str(p))
+                completion_context = self._create_completion_context(
+                    doc_uri, 0, 0, monitor
+                )
 
-        return list_tests(completion_context)
+                if completion_context is None:
+                    continue
+
+                tests.extend(list_tests(completion_context))
+            return tests
+        else:
+            completion_context = self._create_completion_context(doc_uri, 0, 0, monitor)
+            if completion_context is None:
+                return []
+
+            return list_tests(completion_context)
 
     def m_collect_robot_documentation(
         self,
@@ -1033,6 +1073,34 @@ class RobotFrameworkServerApi(PythonLanguageServer):
 
         return doc_highlight(completion_context)
 
+    def m_code_action(self, doc_uri: str, params: TextDocumentCodeActionTypedDict):
+        func = partial(self._threaded_code_action, doc_uri, params)
+        func = require_monitor(func)
+        return func
+
+    def _threaded_code_action(
+        self, doc_uri: str, params: TextDocumentCodeActionTypedDict, monitor: IMonitor
+    ) -> Optional[List[CommandTypedDict]]:
+
+        from robotframework_ls.impl.code_action import code_action
+
+        end = params["range"]["end"]
+        line = end["line"]
+        col = end["character"]
+        completion_context = self._create_completion_context(
+            doc_uri, line, col, monitor
+        )
+        if completion_context is None:
+            return None
+
+        context = params["context"]
+        found_data: List[ICustomDiagnosticDataTypedDict] = []
+        for diagnostic in context["diagnostics"]:
+            data: Optional[ICustomDiagnosticDataTypedDict] = diagnostic.get("data")
+            if data is not None:
+                found_data.append(data)
+        return code_action(completion_context, found_data)
+
     def m_references(
         self, doc_uri: str, line: int, col: int, include_declaration: bool
     ):
