@@ -20,7 +20,7 @@ https://github.com/microsoft/language-server-protocol/tree/gh-pages/_specificati
 https://microsoft.github.io/language-server-protocol/specification
 """
 from __future__ import annotations
-from typing import List, Union, Optional, Any, Tuple, Dict
+from typing import List, Union, Optional, Any, Tuple, Dict, Sequence
 import typing
 
 from robocorp_ls_core.protocols import IEndPoint, IFuture, TypedDict
@@ -451,13 +451,32 @@ class TextDocumentEditTypedDict(TypedDict):
     edits: List[Union[TextEditTypedDict, AnnotatedTextEditTypedDict]]
 
 
+class CreateFileOptions(TypedDict, total=False):
+    overwrite: Optional[bool]
+    ignoreIfExists: Optional[bool]
+
+
+class CreateFileTypedDict(TypedDict, total=False):
+    kind: str  # "create"
+
+    uri: str  # DocumentUri
+
+    options: Optional[CreateFileOptions]
+
+    annotationId: str  # Optional[ChangeAnnotationIdentifier]
+
+
 class WorkspaceEditTypedDict(TypedDict, total=False):
     # Changes to existing docs.
     changes: Dict[str, List[TextEditTypedDict]]
 
     # Changes + resources changes (rename, delete, create)
     # Requires workspace.workspaceEdit.documentChanges client capability
-    documentChanges: Any
+    documentChanges: Union[
+        Sequence[TextDocumentEditTypedDict],
+        Sequence[TextDocumentEditTypedDict],
+        Sequence[CreateFileTypedDict],
+    ]
 
     # Changes with descriptions
     # Requires workspace.changeAnnotationSupport client capability
@@ -506,6 +525,57 @@ class TextDocumentPositionParamsTypedDict(TypedDict, total=False):
     position: PositionTypedDict
 
 
+class DiagnosticsTypedDict(TypedDict):
+    # The range at which the message applies.
+    range: RangeTypedDict
+
+    # The diagnostic's severity. Can be omitted. If omitted it is up to the
+    # client to interpret diagnostics as error, warning, info or hint.
+    severity: Optional[int]  # DiagnosticSeverity
+
+    # The diagnostic's code, which might appear in the user interface.
+    code: Union[int, str]
+
+    # An optional property to describe the error code.
+    #
+    # @since 3.16.0
+    codeDescription: Any
+
+    # A human-readable string describing the source of this
+    # diagnostic, e.g. 'typescript' or 'super lint'.
+    source: Optional[str]
+
+    # The diagnostic's message.
+    message: str
+
+    # Additional metadata about the diagnostic.
+    #
+    # @since 3.15.0
+    tags: list  # DiagnosticTag[];
+
+    # An array of related diagnostic information, e.g. when symbol-names within
+    # a scope collide all definitions can be marked via this property.
+    relatedInformation: list  # DiagnosticRelatedInformation[];
+
+    # A data entry field that is preserved between a
+    # `textDocument/publishDiagnostics` notification and
+    # `textDocument/codeAction` request.
+    #
+    # @since 3.16.0
+    data: Optional[Any]  # unknown;
+
+
+class TextDocumentContextTypedDict(TypedDict, total=False):
+    diagnostics: List[DiagnosticsTypedDict]
+    triggerKind: int
+
+
+class TextDocumentCodeActionTypedDict(TypedDict):
+    textDocument: TextDocumentIdentifierTypedDict
+    range: RangeTypedDict
+    context: TextDocumentContextTypedDict
+
+
 class PrepareRenameParamsTypedDict(TextDocumentPositionParamsTypedDict):
     pass
 
@@ -623,7 +693,7 @@ class CompletionItemTypedDict(TypedDict, total=False):
     # the edit's replace range, that means it must be contained and starting at the same position.
     #
     # @since 3.16.0 additional type `InsertReplaceEdit`
-    textEdit: Optional[Any]  # Union[TextEdit, InsertReplaceEdit]
+    textEdit: Optional[TextEditTypedDict]  # Union[TextEdit, InsertReplaceEdit]
     #
     # An optional array of additional [text edits](#TextEdit) that are applied when
     # selecting this completion. Edits must not overlap (including the same insert position)
@@ -812,11 +882,24 @@ class Location(_Base):
         self.range = range
 
 
+class ShowDocumentParamsTypedDict(TypedDict, total=False):
+    uri: str
+    external: Optional[bool]
+    takeFocus: Optional[bool]
+    selection: Optional[RangeTypedDict]
+
+
+class WorkspaceEditParamsTypedDict(TypedDict, total=False):
+    label: Optional[str]
+    edit: WorkspaceEditTypedDict
+
+
 class LSPMessages(object):
     M_PUBLISH_DIAGNOSTICS = "textDocument/publishDiagnostics"
     M_APPLY_EDIT = "workspace/applyEdit"
     M_SHOW_MESSAGE = "window/showMessage"
     M_SHOW_MESSAGE_REQUEST = "window/showMessageRequest"
+    M_SHOW_DOCUMENT = "window/showDocument"
 
     def __init__(self, endpoint: IEndPoint):
         self._endpoint = endpoint
@@ -825,8 +908,19 @@ class LSPMessages(object):
     def endpoint(self) -> IEndPoint:
         return self._endpoint
 
-    def apply_edit(self, edit):
-        return self._endpoint.request(self.M_APPLY_EDIT, {"edit": edit})
+    def apply_edit_args(self, edit_args: WorkspaceEditParamsTypedDict) -> IFuture:
+        return self._endpoint.request(self.M_APPLY_EDIT, params=edit_args)
+
+    def show_document(self, show_document_args: ShowDocumentParamsTypedDict) -> IFuture:
+        return self._endpoint.request(self.M_SHOW_DOCUMENT, params=show_document_args)
+
+    def apply_edit(
+        self, edit: WorkspaceEditTypedDict, label: Optional[str] = None
+    ) -> IFuture:
+        edit_args: WorkspaceEditParamsTypedDict = {"edit": edit}
+        if label:
+            edit_args["label"] = label
+        return self.apply_edit_args(edit_args)
 
     def publish_diagnostics(self, doc_uri, diagnostics):
         self._endpoint.notify(
@@ -839,7 +933,7 @@ class LSPMessages(object):
             self.M_SHOW_MESSAGE, params={"type": msg_type, "message": message}
         )
 
-    def execute_workspace_command(self, command, arguments):
+    def execute_workspace_command(self, command, arguments) -> IFuture:
         command_future = self._endpoint.request(
             "$/executeWorkspaceCommand",
             {
@@ -871,9 +965,43 @@ class LSPMessages(object):
         )
 
 
+class ICustomDiagnosticDataTypedDict(TypedDict):
+    kind: str
+
+
+class ICustomDiagnosticDataUndefinedKeywordTypedDict(TypedDict):
+    kind: str  # undefined_keyword
+    name: str
+
+
+class ICustomDiagnosticDataUndefinedResourceTypedDict(TypedDict):
+    kind: str  # undefined_resource
+    name: str
+    resolved_name: str
+
+
+class ICustomDiagnosticDataUndefinedVarImportTypedDict(TypedDict):
+    kind: str  # undefined_var_import
+    name: str
+    resolved_name: str
+
+
+class ICustomDiagnosticDataUndefinedLibraryTypedDict(TypedDict):
+    kind: str  # undefined_import
+    name: str
+    resolved_name: str
+
+
+class ICustomDiagnosticDataUnexpectedArgumentTypedDict(TypedDict):
+    kind: str  # unexpected_argument
+    arg_name: str
+    keyword_name: str
+    path: str
+
+
 class Error(object):
 
-    __slots__ = "msg start end severity tags".split(" ")
+    __slots__ = "msg start end severity tags data".split(" ")
 
     def __init__(
         self,
@@ -889,6 +1017,7 @@ class Error(object):
         self.start = start
         self.end = end
         self.severity = severity
+        self.data: Any = None
 
     def to_dict(self):
         ret = {
@@ -900,6 +1029,8 @@ class Error(object):
         tags = getattr(self, "tags", None)
         if tags:
             ret["tags"] = tags
+        if self.data is not None:
+            ret["data"] = self.data
         return ret
 
     def __repr__(self):
@@ -922,4 +1053,6 @@ class Error(object):
         }
         if tags:
             ret["tags"] = tags
+        if self.data is not None:
+            ret["data"] = self.data
         return ret
