@@ -334,6 +334,11 @@ class IRobotFrameworkApiClient(ILanguageServerClientBase, Protocol):
         :Note: async complete.
         """
 
+    def request_flow_explorer_model(self, doc_uri) -> Optional[IIdMessageMatcher]:
+        """
+        :Note: async complete.
+        """
+
     def request_rename(
         self, doc_uri: str, line: int, col: int, new_name: str
     ) -> Optional[IIdMessageMatcher]:
@@ -410,6 +415,17 @@ class IRobotFrameworkApiClient(ILanguageServerClientBase, Protocol):
         :Note: async complete.
         """
 
+    def request_collect_robot_documentation(
+        self,
+        doc_uri,
+        library_name: Optional[str] = None,
+        line: Optional[int] = None,
+        col: Optional[int] = None,
+    ) -> Optional[IIdMessageMatcher]:
+        """
+        :Note: async complete.
+        """
+
     def request_rf_info(self, doc_uri: str) -> Optional[IIdMessageMatcher]:
         """
         :Note: async complete.
@@ -696,7 +712,11 @@ class IDocumentSelection(Protocol):
         pass
 
     @property
-    def line_to_column(self):
+    def line_to_column(self) -> str:
+        pass
+
+    @property
+    def line_to_end(self) -> str:
         pass
 
     @property
