@@ -17,7 +17,7 @@
 # limitations under the License.
 import io
 import os
-from typing import Optional, Dict, List, Iterable, Tuple, Set
+from typing import Optional, Dict, List, Iterable, Tuple, Set, Union, Any
 
 from robocorp_ls_core import uris
 from robocorp_ls_core.basic import implements
@@ -35,6 +35,8 @@ from robocorp_ls_core.lsp import (
     TextDocumentItem,
     TextDocumentContentChangeEvent,
     RangeTypedDict,
+    TextEditTypedDict,
+    TextEdit,
 )
 import weakref
 from collections import namedtuple
@@ -46,6 +48,11 @@ log = get_logger(__name__)
 _FileMTimeInfo = namedtuple("_FileMTimeInfo", "st_mtime, st_size")
 
 
+def _text_edit_key(text_edit: Union[TextEditTypedDict, TextEdit]):
+    start = text_edit["range"]["start"]
+    return start["line"], start["character"]
+
+
 class _DirInfo(object):
     def __init__(self, scan_path):
         self.scan_path = scan_path
@@ -852,9 +859,13 @@ class Document(object):
 
         self._source = new.getvalue()
 
-    def apply_text_edits(self, text_edits):
+    def apply_text_edits(
+        self, text_edits: Union[List[TextEditTypedDict], List[TextEdit]]
+    ):
         self._check_in_mutate_thread()
-        for text_edit in reversed(text_edits):
+        sorted_text_edits = reversed(sorted(text_edits, key=_text_edit_key))
+        text_edit: Any
+        for text_edit in sorted_text_edits:
             self._apply_change(text_edit["range"], text_edit["newText"])
 
     def find_line_with_contents(self, contents: str) -> int:
